@@ -9,11 +9,15 @@ from __future__ import absolute_import
 from __future__ import unicode_literals
 
 import copy
+from pathlib import Path
+import datetime
 
 from ngoschema.utils.utils import Context
 from ngoschema import settings
 
-DEFAULT_CONTEXT = Context(**settings.DEFAULT_CONTEXT)
+from ..decorators import assert_arg
+
+DEFAULT_CONTEXT = Context(settings.DEFAULT_CONTEXT, today=datetime.date.today())
 
 
 class Context:
@@ -32,7 +36,8 @@ class Context:
     @staticmethod
     def _create_context(self, *parents, context=None, **local):
         context = context or self._context
-        ctx = context.create_child(*parents, **local)
+        # create a new today at every context creation, will update the DEFAULT_CONTEXT value
+        ctx = context.create_child(*parents, today=datetime.date.today(), **local)
         ctx._session = getattr(context, '_session', None)
         return ctx
 
